@@ -13,8 +13,7 @@
 #include <QtGui/QTableWidget>
 
 #include "course-dialog.h"
-#include "cell-delegate.h"
-
+#include "score-common.h"
 
 CourseSelectDialog::CourseSelectDialog(QWidget *parent) : QDialog(parent)
 {
@@ -135,13 +134,12 @@ void CourseDialog::createTable(QWidget *parent)
   table->horizontalHeader()->hide();
   table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
   table->verticalHeader()->setResizeMode(QHeaderView::Stretch);
+  table->setStyleSheet(ScoreColor::styleSheet());
 }
 
 void CourseDialog::init(Course *course)
 {
   QTableWidgetItem *par, *hcp;
-  QColor fgColor(Qt::white);
-  QColor bgColor(Qt::darkGray);
 
   for (int i=0; i<18; i++) {
     if (course) {
@@ -155,8 +153,7 @@ void CourseDialog::init(Course *course)
     QTableWidgetItem *len = new QTableWidgetItem("");
 
     QTableWidgetItem *holeNum = new QTableWidgetItem(QString::number(i+1));
-    holeNum->setTextColor(fgColor);
-    holeNum->setBackgroundColor(bgColor);
+    holeNum->setBackgroundColor(ScoreColor::holeBg());
 
     holeNum->setTextAlignment(Qt::AlignCenter);
     par->setTextAlignment(Qt::AlignCenter);
