@@ -35,8 +35,8 @@ public:
   void setMode(int m);
   int mode(void);
   void setScore(QList<Score *> &sList, Score *score = 0);
-  Score *getScore(void);
   void setClub(QList<Club *> &cList);
+  Score *getScore(void);
   Club *getClub(void);
   Course *getCourse(void);
 
@@ -61,9 +61,20 @@ public:
 
  private:
   int currentMode;
-  enum { ROWS = 8, COLS = 9 };
-  enum { ROW_HOLE = 0, ROW_PAR = 1, ROW_HCP = 2, ROW_SCORE = 3, 
-	 ROW_HOLE_2 = 4, ROW_PAR_2 = 5, ROW_HCP_2 = 6, ROW_SCORE_2 = 7};
+  enum { 
+    ROWS = 8, 
+    COLS = 9 
+  };
+  enum { 
+    ROW_HOLE = 0, 
+    ROW_PAR = 1, 
+    ROW_HCP = 2, 
+    ROW_SCORE = 3, 
+    ROW_HOLE_2 = 4, 
+    ROW_PAR_2 = 5, 
+    ROW_HCP_2 = 6, 
+    ROW_SCORE_2 = 7
+  };
 
   QList<Score *> scoreList;
   QList<Club *> clubList;
